@@ -1,7 +1,7 @@
         
 class M1CNNPreprocessing:
     @staticmethod
-    def preprocess_features(self, dataframe):
+    def preprocess_features(dataframe):
         from EIMTC.plugins.n_bytes import NBytes
         NBytes.preprocess(dataframe)
         
